@@ -7,7 +7,7 @@ test_that("Errors in Modfed function", {
   pd <- MASS::mvrnorm(n = 1, mu = mu, Sigma = v) # 10 draws.
   #p.d <- list(NA, pd[,2:6])
   expect_error(Modfed(cand.set = cand.set, n.sets = 8, n.alts = 2, 
-         alt.cte = c(1,0), parallel = FALSE, par.draws = pd, best = T),
+         alt.cte = c(1,0), parallel = FALSE, par.draws = pd),
          "par.draws should be a list")
   
   # 1 alternative constant in a choice set with 2 alternatives
@@ -17,5 +17,5 @@ test_that("Errors in Modfed function", {
   pd <- MASS::mvrnorm(n = 2, mu = mu, Sigma = v) # 10 draws.
   p.d <- list(matrix(pd[,1], ncol = 1), pd[,2:7])
   expect_error(Modfed(cand.set = cand.set, n.sets = 8, n.alts = 2, 
-         alt.cte = NULL, parallel = FALSE, par.draws = p.d, best = T))
+         alt.cte = NULL, parallel = FALSE, par.draws = p.d))
 })
\ No newline at end of file
